@@ -553,22 +553,23 @@ void sinsp_chisel::parse_view_columns(lua_State *ls, OUT chisel_desc* cd, OUT vo
 	}
 }
 
-void sinsp_chisel::parse_view_hotkey(lua_State *ls, OUT chisel_desc* cd, OUT void* hotkeys)
+void sinsp_chisel::parse_view_action(lua_State *ls, OUT chisel_desc* cd, OUT void* actions)
 {
-	vector<sinsp_view_hotkey_info>* keys = (vector<sinsp_view_hotkey_info>*)hotkeys;
+	vector<sinsp_view_action_info>* keys = (vector<sinsp_view_action_info>*)actions;
 
 	lua_pushnil(ls);
 
-	char key;
+	char key = 0;
 	string command;
 	string description;
 	string tmpstr;
+	bool waitfinish = true;
 
 	while(lua_next(ls, -2) != 0)
 	{
 		string fldname = lua_tostring(ls, -2);
 
-		if(fldname == "key")
+		if(fldname == "hotkey")
 		{
 			tmpstr = lua_tostring(ls, -1);
 			if(tmpstr.size() == 1)
@@ -577,7 +578,7 @@ void sinsp_chisel::parse_view_hotkey(lua_State *ls, OUT chisel_desc* cd, OUT voi
 			}
 			else
 			{
-				throw sinsp_exception("hotkey 'key' fileld must be a single character string");
+				throw sinsp_exception("action 'key' field must be a single character string");
 			}
 		}
 		else if(fldname == "command")
@@ -588,16 +589,36 @@ void sinsp_chisel::parse_view_hotkey(lua_State *ls, OUT chisel_desc* cd, OUT voi
 		{
 			description = lua_tostring(ls, -1);
 		}
+		else if(fldname == "wait_finish")
+		{
+			int wf = lua_toboolean(ls, -1);
+
+			if(wf == 0)
+			{
+				waitfinish = false;
+			}
+		}
 
 		lua_pop(ls, 1);
 	}
 
-	keys->push_back(sinsp_view_hotkey_info(key, 
+	if(key == 0)
+	{
+		throw sinsp_exception("action missing the 'key' value");
+	}
+
+	if(command == "")
+	{
+		throw sinsp_exception("action missing the 'command' value");
+	}
+
+	keys->push_back(sinsp_view_action_info(key, 
 		command,
-		description));
+		description,
+		waitfinish));
 }
 
-void sinsp_chisel::parse_view_hotkeys(lua_State *ls, OUT chisel_desc* cd, OUT void* hotkeys)
+void sinsp_chisel::parse_view_actions(lua_State *ls, OUT chisel_desc* cd, OUT void* actions)
 {
 	string name;
 	string type;
@@ -609,11 +630,11 @@ void sinsp_chisel::parse_view_hotkeys(lua_State *ls, OUT chisel_desc* cd, OUT vo
 	{
 		if(lua_istable(ls, -1))
 		{
-			parse_view_hotkey(ls, cd, hotkeys);
+			parse_view_action(ls, cd, actions);
 		}
 		else
 		{
-			throw sinsp_exception("view_info hotkey entries must be tables");
+			throw sinsp_exception("view_info action entries must be tables");
 		}
 
 		lua_pop(ls, 1);
@@ -640,7 +661,7 @@ bool sinsp_chisel::parse_view_info(lua_State *ls, OUT chisel_desc* cd)
 	bool use_defaults = false;
 	sinsp_view_info::viewtype vt = sinsp_view_info::T_TABLE;
 	vector<sinsp_view_column_info> columns;
-	vector<sinsp_view_hotkey_info> hotkeys;
+	vector<sinsp_view_action_info> actions;
 	vector<string> tags;
 	vector<string> tips;
 	string drilldown_target;
@@ -798,11 +819,11 @@ bool sinsp_chisel::parse_view_info(lua_State *ls, OUT chisel_desc* cd)
 				throw sinsp_exception("error in view " + cd->m_name + ": " + string(lua_tostring(ls, -2)) + " is not a table");
 			}
 		}
-		else if(fldname == "hotkeys")
+		else if(fldname == "actions")
 		{
 			if(lua_istable(ls, -1))
 			{
-				parse_view_hotkeys(ls, cd, &hotkeys);
+				parse_view_actions(ls, cd, &actions);
 			}
 			else
 			{
@@ -825,7 +846,7 @@ bool sinsp_chisel::parse_view_info(lua_State *ls, OUT chisel_desc* cd)
 		drilldown_target,
 		use_defaults,
 		is_root,
-		hotkeys);
+		actions);
 
 	return true;
 }
