@@ -33,6 +33,8 @@ public:
 	// Processing entry point
 	//
 	void process_event(sinsp_evt* evt);
+	void event_cleanup(sinsp_evt* evt);
+
 	void erase_fd(erase_fd_params* params);
 
 	//
@@ -116,6 +118,8 @@ private:
 	// Return false if the update didn't happen because the tuple is identical to the given address
 	bool set_unix_info(sinsp_fdinfo_t* fdinfo, uint8_t* packed_data);
 	void swap_ipv4_addresses(sinsp_fdinfo_t* fdinfo);
+	uint8_t* reserve_event_buffer();
+	void free_event_buffer(uint8_t*);
 
 	//
 	// Pointers to inspector context
@@ -134,6 +138,7 @@ private:
 	//
 	vector<sinsp_protodecoder*> m_protodecoders;
 
+	stack<uint8_t*> m_tmp_events_buffer;
 	friend class sinsp_analyzer;
 	friend class sinsp_analyzer_fd_listener;
 	friend class sinsp_protodecoder;
