@@ -713,7 +713,8 @@ void sinsp_thread_manager::add_thread(sinsp_threadinfo& threadinfo, bool from_sc
 
 	m_last_tinfo = NULL;
 
-	if(m_threadtable.size() >= m_inspector->m_max_thread_table_size)
+	if(m_threadtable.size() >= m_inspector->m_max_thread_table_size &&
+			threadinfo.m_pid != m_inspector->m_sysdig_pid)
 	{
 		m_n_drops++;
 		return;
